==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebMRLColumnSizeInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLColumnSizeInfoDescription } from "./WebMRLColumnSizeInfoDescription";
/**
 * @hidden
 */
var WebMRLColumnSizeInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMRLColumnSizeInfoDescriptionMetadata, _super);
    function WebMRLColumnSizeInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMRLColumnSizeInfoDescriptionMetadata.b = function (a) {
        if (WebMRLColumnSizeInfoDescriptionMetadata.a == null) {
            WebMRLColumnSizeInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMRLColumnSizeInfoDescriptionMetadata.c(WebMRLColumnSizeInfoDescriptionMetadata.a);
        }
        if (a.j(WebMRLColumnSizeInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(WebMRLColumnSizeInfoDescriptionMetadata.a);
    };
    WebMRLColumnSizeInfoDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:MRLColumnSizeInfo");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebMRLColumnSizeInfoDescriptionMetadata.d = function (a) {
        WebMRLColumnSizeInfoDescriptionMetadata.b(a);
        a.aa("WebMRLColumnSizeInfo", function () { return new WebMRLColumnSizeInfoDescription(); });
        a.z("WebMRLColumnSizeInfo", WebMRLColumnSizeInfoDescriptionMetadata.a);
    };
    WebMRLColumnSizeInfoDescriptionMetadata.$t = markType(WebMRLColumnSizeInfoDescriptionMetadata, 'WebMRLColumnSizeInfoDescriptionMetadata');
    WebMRLColumnSizeInfoDescriptionMetadata.a = null;
    return WebMRLColumnSizeInfoDescriptionMetadata;
}(Base));
export { WebMRLColumnSizeInfoDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebMRLColumnSizeInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLColumnSizeInfoDescription } from "./WebMRLColumnSizeInfoDescription";
/**
 * @hidden
 */
var WebMRLColumnSizeInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMRLColumnSizeInfoDescriptionMetadata, _super);
    function WebMRLColumnSizeInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMRLColumnSizeInfoDescriptionMetadata.b = function (a) {
        if (WebMRLColumnSizeInfoDescriptionMetadata.a == null) {
            WebMRLColumnSizeInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMRLColumnSizeInfoDescriptionMetadata.c(WebMRLColumnSizeInfoDescriptionMetadata.a);
        }
        if (a.k(WebMRLColumnSizeInfoDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebMRLColumnSizeInfoDescriptionMetadata.a);
    };
    WebMRLColumnSizeInfoDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:MRLColumnSizeInfo");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebMRLColumnSizeInfoDescriptionMetadata.d = function (a) {
        WebMRLColumnSizeInfoDescriptionMetadata.b(a);
        a.ac("WebMRLColumnSizeInfo", function () { return new WebMRLColumnSizeInfoDescription(); });
        a.ab("WebMRLColumnSizeInfo", WebMRLColumnSizeInfoDescriptionMetadata.a);
    };
    WebMRLColumnSizeInfoDescriptionMetadata.$t = markType(WebMRLColumnSizeInfoDescriptionMetadata, 'WebMRLColumnSizeInfoDescriptionMetadata');
    WebMRLColumnSizeInfoDescriptionMetadata.a = null;
    return WebMRLColumnSizeInfoDescriptionMetadata;
}(Base));
export { WebMRLColumnSizeInfoDescriptionMetadata };
